@@ -1,8 +1,8 @@
 package Data::AMF;
 use 5.008001;
-use Moose;
+use Any::Moose;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Data::AMF::Parser;
 use Data::AMF::Formatter;
@@ -31,7 +31,7 @@ has formatter => (
     },
 );
 
-__PACKAGE__->meta->make_immutable;
+no Any::Moose;
 
 sub serialize {
     my $self = shift;
@@ -43,6 +43,10 @@ sub deserialize {
     $self->parser->parse(@_);
 }
 
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
 =head1 NAME
 
 Data::AMF - serialize / deserialize AMF data
@@ -113,5 +117,3 @@ The full text of the license can be found in the
 LICENSE file included with this module.
 
 =cut
-
-1;
